@@ -53,19 +53,19 @@ from tornado.web import Application as TApplication, url
 
 import univention.debug as ud
 from univention.management.console import saml
-from univention.management.console.config import ucr
+from univention.management.console.config import SQL_CONNECTION_ENV_VAR, ucr
 from univention.management.console.log import CORE, log_init, log_reopen
 from univention.management.console.oidc import (
     OIDCBackchannelLogout, OIDCFrontchannelLogout, OIDCLogin, OIDCLogout, OIDCLogoutFinished, OIDCMetadata,
 )
 from univention.management.console.resources import (
     UCR, Auth, Categories, Command, GetIPAddress, Hosts, Index, Info, Logout, Meta, Modules, NewSession, Nothing,
-    SessionInfo, Set, SetLocale, SetPassword, SetUserPreferences, Upload, UserPreferences,
+    SessionInfo, Set, SetLocale, SetPassword, SetUserPreferences, SSELogoutNotifer, Upload, UserPreferences,
 )
 from univention.management.console.saml import SamlACS, SamlIframeACS, SamlLogout, SamlMetadata, SamlSingleLogout
 from univention.management.console.session import categoryManager, moduleManager
 from univention.management.console.shared_memory import shared_memory
-from univention.management.console.sse import SSELogoutNotifer
+from univention.udm import UDM
 
 
 try:
@@ -225,6 +225,16 @@ class Server(object):
         # bind sockets
         sockets = bind_sockets(self.options.port, ucr.get('umc/http/interface', '127.0.0.1'), backlog=ucr.get_int('umc/http/requestqueuesize', 100), reuse_port=True)
 
+        if os.environ.get(SQL_CONNECTION_ENV_VAR, None) is None:
+            try:
+                settings_data_mod = UDM.machine().version(3).get('settings/data')
+                umc_settings_position = f"cn=umc,cn=data,cn=univention,{ucr.get('ldap/base')}"
+                umc_settings_obj = settings_data_mod.get(umc_settings_position)
+                settings_obj = json.loads(umc_settings_obj.props.data.raw.decode('utf-8'))
+                os.environ[SQL_CONNECTION_ENV_VAR] = settings_obj['sqlURI']
+            except Exception as exc:
+                CORE.info('Could not read from umc settings/data object. Continuing without shared db session %s' % (exc,))
+
         # start sub worker processes
         if self.options.processes != 1:
             # start sharing memory (before fork, before first usage, after import)
